@@ -20,7 +20,6 @@
 #include <QPushButton>
 #include <QStackedWidget>
 #include <QVBoxLayout>
-#include <kwidgetsaddons_version.h>
 
 using namespace ContactEditor;
 
@@ -93,13 +92,9 @@ AddressLocationWidget::AddressLocationWidget(QWidget *parent)
     label = new QLabel(KContacts::Address::countryLabel(), this);
     label->setObjectName(QStringLiteral("countrylabel"));
     gridLayout->addWidget(label, 5, 1);
-    mCountryCombo = new KComboBox(this);
-    auto edit = new KLineEdit(this);
-    edit->setTrapReturnKey(true);
-    mCountryCombo->setLineEdit(edit);
+    mCountryCombo = new QComboBox(this);
     mCountryCombo->setObjectName(QStringLiteral("countrycombobox"));
-    mCountryCombo->setEditable(true);
-    mCountryCombo->lineEdit()->setPlaceholderText(i18n("Add a Country"));
+    mCountryCombo->setEditable(false);
     mCountryCombo->setDuplicatesEnabled(false);
     connect(mCountryCombo, &KComboBox::textHighlighted, this, &AddressLocationWidget::slotChanged);
     gridLayout->addWidget(mCountryCombo, 6, 1);
@@ -197,9 +192,6 @@ void AddressLocationWidget::fillCountryCombo()
     });
 
     mCountryCombo->addItems(countries);
-    mCountryCombo->setAutoCompletion(true);
-    mCountryCombo->completionObject()->setItems(countries);
-    mCountryCombo->completionObject()->setIgnoreCase(true);
 
     const QString currentCountry = QLocale::countryToString(QLocale().country());
     mCountryCombo->setCurrentIndex(mCountryCombo->findText(currentCountry));
@@ -289,20 +281,12 @@ void AddressLocationWidget::slotUpdateAddress()
 void AddressLocationWidget::slotRemoveAddress()
 {
     if (mCurrentMode == ModifyAddress) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         const auto result = KMessageBox::questionTwoActions(this,
-#else
-        const auto result = KMessageBox::questionYesNo(this,
-#endif
                                                             i18n("Do you really want to delete this address?"),
                                                             QString(),
                                                             KStandardGuiItem::del(),
                                                             KStandardGuiItem::cancel());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (result == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-        if (result == KMessageBox::Yes) {
-#endif
             Q_EMIT removeAddress(mCurrentAddress);
             reset();
         }
